<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="fi" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">Yleistä</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategoria:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Aloita torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Ohita tarkistussumman laskeminen</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Luo alikansio</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Luokittelemattomia</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Lisää kategoria...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Poista kategoria</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Poista käyttämättömät kategoriat</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Jatka torrentteja</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Keskeytä torrentit</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Poista torrentit</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Uusi kategoria</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Muokkaa kategoriaa...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Sulje qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Vain yksi linkki riville</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Yleisen lähetysnopeusrajoituksen täytyy olla suurempi kuin 0, tai poissa käytöstä.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Yleisen latausnopeusrajoituksen täytyy olla suurempi kuin 0, tai poissa käytöstä.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Vaihtoehtoisen lähetyksen rajan pitää olla suurempi kuin 0, tai poissa käytöstä.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Vaihtoehtoisen latauksen rajan pitää olla suurempi kuin 0, tai poissa käytöstä.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Aktiivisten latauksien enimmäismäärä pitää olla suurempi kuin -1</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Aktiivisten jakojen enimmäismäärä pitää olla suurempi kuin -1</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Aktiiivisten torrenttien enimmäismäärä pitää olla suurempi kuin -1</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Yhteyksien enimmäismäärän pitää olla suurempi kuin 0 tai poistettu käytöstä.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Yhteyksien torrenttikohtaisen maksimimäärän pitää olla suurempi kuin 0 tai poistettu käytöstä.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Lähetyslohkojen torrenttikohtaisen enimmäismäärän pitää olla suurempi kuin 0 tai poistettu käytöstä.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Asetuksia ei voitu tallentaa, qBittorrenttiin ei todennäköisesti saada yhteyttä.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent Freenode-verkossa</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Jakosuhteen raja pitää olla 0 ja 9998 välillä.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Sisääntuleville yhteyksille tarkoitetun portin numero pitää olla väliltä 1-65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Web-käyttöliittymälle tarkoitetun portin numero pitää olla väliltä 1-65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Kirjautuminen epäonnistui, qBittorrent ei luultavasti ole tavoitettavissa.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Virheellinen käyttäjätunnus tai salasana.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjänimi</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Alkuperäiset tekijät</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Toteuta</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Lähetä torrentit</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Latauskansio:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Eväste:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Kirjoita kansio tähän</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Lisää tietoa</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Tietoa varmenteista</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Aseta sijainti</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Rajoita lähetysnopeutta</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Rajoita latausnopeutta</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Nimeä uudelleen torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Muu...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Maanantai</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Tiistai</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Keskiviikko</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Torstai</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Perjantai</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Lauantai</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sunnuntai</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Lataa torrentteja niiden URL-osoitteista tai Magnet-linkeistä</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Haluatko varmasti poistaa valitut torrentit?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent ei vastaa</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to create category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Vapaata tilaa: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Saving Management</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Open documentation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Työkalut</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Asetukset...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Työkalupalkki</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Tilapalkki</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Nopeudet otsikkorivillä</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Lahjoita!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Jatka kaikkia</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Tilastot</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pysäytä kaikki</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Lisää torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentaatio</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Avaa torrent osoitteesta...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ei</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Yleinen lähetysnopeusrajoitus</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Yleinen latausnopeusrajoitus</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Haluatko varmasti lopettaa qBittorrentin?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[Lataus: %1, Lähetys: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Hakukone</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Transfers</source>
        <translation>Siirrot</translation>
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Top of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Yhteys</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Nopeus</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web-käyttöliittymä</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Kieli</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Käyttöliittymän kieli:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Sähköposti-ilmoitus latauksen valmistuttua</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Suorita erillinen ohjelma torrentien valmistuessa</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP-suodatus</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Aseta aikataulu vaihtoehtoisille nopeusrajoituksille</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrentien jonotus</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Lisää nämä seurantapalvelimet automaattisesti uusiin latauksiin:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Web-käyttöliittymä (Etäohjaus)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP osoite:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Palvelimen verkkotunnukset:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Käytä HTTPS:ää HTTP:n sijaan</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Päivitä dynaamisen verkkotunnukseni nimi</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Säilytä keskeneräiset torrentit kohteeseen:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopioi .torrent-tiedostot kohteeseen:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopioi valmistuneiden latausten .torrent-tiedostot kohteeseen:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Varaa kaikille tiedostoille levytila ennakkoon</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Lisää .!qB pääte keskeneräisille tiedostoille</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Lisää torrentit automaattisesti kohteesta:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-palvelin:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Tämä palvelin vaatii suojatun yhteyden (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Tunnistautuminen</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Käyttäjänimi:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Käytössä oleva protokolla:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP ja μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Kuunteluportti</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Portti sisääntuleville yhteyksille:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Käytä UPnP-/NAT-PMP-portinohjausta reitittimeltä</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Käytä eri porttia joka käynnistyksen yhteydessä</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Yhteyksien rajat</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Yhteyksien enimmäismäärä torrenttia kohden:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Kaikkien yhteyksien enimmäismäärä:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Lähetyspaikkojen enimmäismäärä torrentia kohden:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Kaikkien lähetyspaikkojen enimmäismäärä:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Välityspalvelin</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tyyppi:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Ei mikään)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Isäntä:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Portti:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Käytä välityspalvelinta vertaisyhteyksille</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Käytä välityspalvelinta vain torrenteille</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Suodatustiedoston sijainti (.dat, .p2p, p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Manuaalisesti kielletyt IP-osoitteet...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Yleiset nopeusrajoitukset</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Lähetys:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Lataus:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Vaihtoehtoiset nopeusrajoitukset</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Alkaen:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Loppuu:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Ajankohta:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Joka päivä</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Arkisin</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Viikonloppuisin</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Nopeusrajoitusasetukset</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Käytä nopeusrajoitusta µTP-protokollaan</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Yksityisyys</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Käytä DHT:tä (hajautettua verkkoa) useampien käyttäjien löytämiseen</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Käytä PeX:tä löytääksesi enemmän käyttäjiä</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Käytä paikallista hakua löytääksesi enemmän käyttäjiä (LPD)</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Salaustila:</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Vaadi salaus</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Ei salausta</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Käytä anonyymitilaa</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Aktiivisia latauksia enintään:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Aktiivisia lähetettäviä torrentteja enintään:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Aktiivisia torrentteja enintään:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Älä laske hitaita torrenteja näihin rajoituksiin</translation>
    </message>
    <message>
        <source>then</source>
        <translation>sitten</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Varmenne:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Avain:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Verkkotunnuksen nimi:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Tuetut parametrit (kirjainkoolla on merkitystä):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrentin nimi</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategoria</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Juuripolku (ensimmäinen torrent-alihakemiston polku)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Tallennussijainti</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Tiedostojen määrä</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrenin koko (tavua)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Nykyinen seurantapalvelin</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Web-käyttöliittymän käyttäjätunnuksen pitää olla vähintään 3 merkkiä pitkä.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Web-käyttöliittymän salasanan pitää olla vähintään 6 merkkiä pitkä.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB/s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Change current password</source>
        <translation>Vaihda nykyinen salasana</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files location:</source>
        <translation>Tiedostojen sijainti:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Strict super seeding:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate based</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Anti-leech</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>sec</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>File pool size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Any interface</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fastest upload</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fixed slots</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resolve peer countries (GeoIP):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>min</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Round-robin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Listen on IPv6 address (requires restart):</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Liput</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Yhteys</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Asiakassovellus</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Edistyminen</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Latausnopeus</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Lähetysnopeus</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Ladattu</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Lähetetty</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Merkityksellisyys</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Tiedostot</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Maa</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normaali</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Korkea</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Korkein</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not download</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Seurantapalvelimet</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Lataajat</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP-lähteet</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Sisältö</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Ladattu:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Siirto</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Aikaa aktiivisena:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Aika:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Lähetetty:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Jakajia:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Latausnopeus:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Lähetysnopeus:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Lataajia:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Latausraja:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Lähetysraja:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Hukattu:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Yhteydet:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Kommentti:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Jakosuhde:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Julkaise uudelleen:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Viimeksi Nähty Valmistuneen:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Koko yhteensä:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Osia:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Luonut:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Lisätty:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Valmistunut:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Luotu:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrentin tarkistussumma:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Tallennussijainti:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Ei koskaan</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (tässä istunnossa %2)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (enintään %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 yhteensä)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (keskimäärin %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Latausraja:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Lähetysraja:</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter files...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Valvottu Kansio</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Valvottu kansio</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Oletus tallennussijainti</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Tilastot</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Käyttäjätilastot</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Välimuistitilastot</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Luetut välimuistin osumat:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Keskimääräinen aika jonossa:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time download:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session waste:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time upload:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Suorituskykytilastot</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Jonoon asetetut I/O-työt:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Kirjoitusvälimuistin ylikuormitus:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Lukuvälimuistin ylikuormitus:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Jonotettu koko yhteensä:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 solmua</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Kaikki (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Ladataan (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Jakaa (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Valmiina (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Jatkettu (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Keskeytetty (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktiivisena (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Ei aktiivisena (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Virheelliset (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Kaikki (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Ladataan (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Jakaa (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Valmiina (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Keskeytetty (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Jatkettu (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktiivisena (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Ei aktiivisena (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Virheelliset (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Koko</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Jakajia</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Lataajia</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Latausnopeus</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Lähetysnopeus</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Jakosuhde</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Aika</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Tunnisteet</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Lisätty</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Valmistunut</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Seurantapalvelin</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Latausraja</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Lähetysraja</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Ladattu</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Lähetetty</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Ladattu Tässä Istunnossa</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Lähetetty Tässä Istunnossa</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Jäljellä</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Aikaa aktiivisena</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Tallennussijainti</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Valmistunut</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Jakosuhteen raja</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Viimeksi Nähty Valmistuneen</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Viimeisin Toiminta</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Koko yhteensä</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>Verkko-osoite</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Käyttäjät</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Viesti</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Updating...</source>
        <translation>Päivitetään...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker editing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leeches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tracker</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tier</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Seurantapalvelimien lisäys</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lisättävien seurantapalvelimien lista (yksi per rivi):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 sitten</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Moving</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Missing Files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued for checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking resume data</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategoriat</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrentin latausnopeuden rajoitus</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrentin lähetysnopeuden rajoitus</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Pakota jatkaminen</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Rajoita jakosuhde...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Rajoita lähetysnopeus...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Rajoita latausnopeus...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Siirrä ylös jonossa</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Siirrä alas jonossa</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Siirrä jonon kärkeen</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Siirrä jonon viimeiseksi</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Aseta kohdekansio...</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Lataa ensin ensimmäinen ja viimeinen osa</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automaattinen torrentien hallintatila</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Uusi...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Palauta</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Pakota uudelleentarkistus</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>super seed -tila</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Nimeä uudelleen...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Lataa järjestyksessä</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New Category</source>
        <translation>Uusi kategoria</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Uusi nimi</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Aseta sijainti</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Muokkaa kategoriaa</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Magnet link</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Käytä yleistä jako rajoitusta</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set share limit to</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>ratio</source>
        <translation>Jakosuhde</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuuttia</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Poistamisen vahvistus</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Poista tiedostot myös kiintolevyltä</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Lataa verkko-osoitteista</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Lataa</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 h %2 min</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 d %2 h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Tuntematon</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>alle minuutti</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 min</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>URL or local directory</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Asenna liitännäinen</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All plugins</source>
        <translation>Kaikki liitännäiset</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Koko:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Results (showing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent names only</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Only enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>out of</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Everywhere</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Poista asennus</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Asenna uusi liitännäinen</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Asennetut hakuliitännäiset:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Käytössä</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Tarkista päivitykset</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Hakuliitännäiset</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search engine</source>
        <translation>Hakukone</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add tag...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tag:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resume torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tag</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Untagged</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Forum:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Current maintainer</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Greece</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Special Thanks</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Libraries</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Translators</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Nationality:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Open description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download link</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>